==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/PUSHNOTIFICATIONREGISTRYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PUSHNOTIFICATIONREGISTRYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PUSHNOTIFICATIONREGISTRYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEDEVICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEAPPID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PUSHNOTIFICATIONREGISTRYID_Type", propOrder = {
    "mobiledeviceid",
    "mobileappid"
})
public class PUSHNOTIFICATIONREGISTRYID_Type {

    @XmlElement(name = "MOBILEDEVICEID", required = true)
    protected String mobiledeviceid;
    @XmlElement(name = "MOBILEAPPID", required = true)
    protected String mobileappid;

    /**
     * Gets the value of the mobiledeviceid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEDEVICEID() {
        return mobiledeviceid;
    }

    /**
     * Sets the value of the mobiledeviceid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEDEVICEID(String value) {
        this.mobiledeviceid = value;
    }

    /**
     * Gets the value of the mobileappid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEAPPID() {
        return mobileappid;
    }

    /**
     * Sets the value of the mobileappid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEAPPID(String value) {
        this.mobileappid = value;
    }

}

==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/PUSHNOTIFICATIONREGISTRYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PUSHNOTIFICATIONREGISTRYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PUSHNOTIFICATIONREGISTRYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEDEVICEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MOBILEAPPID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PUSHNOTIFICATIONREGISTRYID_Type", propOrder = {
    "mobiledeviceid",
    "mobileappid"
})
public class PUSHNOTIFICATIONREGISTRYID_Type {

    @XmlElement(name = "MOBILEDEVICEID", required = true)
    protected String mobiledeviceid;
    @XmlElement(name = "MOBILEAPPID", required = true)
    protected String mobileappid;

    /**
     * Obtient la valeur de la propriété mobiledeviceid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEDEVICEID() {
        return mobiledeviceid;
    }

    /**
     * Définit la valeur de la propriété mobiledeviceid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEDEVICEID(String value) {
        this.mobiledeviceid = value;
    }

    /**
     * Obtient la valeur de la propriété mobileappid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMOBILEAPPID() {
        return mobileappid;
    }

    /**
     * Définit la valeur de la propriété mobileappid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMOBILEAPPID(String value) {
        this.mobileappid = value;
    }

}
